@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataCSel::Parsing;
 
-our $DATE = '2016-04-12'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark parsing speed',
@@ -35,7 +35,7 @@ Bencher::Scenario::DataCSel::Parsing - Benchmark parsing speed
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::DataCSel::Parsing (from Perl distribution Bencher-Scenarios-DataCSel), released on 2016-04-12.
+This document describes version 0.04 of Bencher::Scenario::DataCSel::Parsing (from Perl distribution Bencher-Scenarios-DataCSel), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -49,11 +49,15 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Data::CSel> 0.07
+L<Data::CSel> 0.11
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -87,33 +91,34 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DataCSel::Parsing >>):
 
+ #table1#
  +---------------------+-----------+-----------+------------+---------+---------+
- | dataset             | rate (/s) | time (μs) | vs_slowest | errors  | samples |
+ | dataset             | rate (/s) | time (μs) | vs_slowest |  errors | samples |
  +---------------------+-----------+-----------+------------+---------+---------+
- | :has(T[length > 1]) | 30739.1   | 32.5319   | 1          | 0       | 20      |
- | T ~ T ~ T ~ T ~ T   | 4.8e+04   | 21        | 1.6        | 2.6e-08 | 21      |
- | T T2 T3 T4 T5       | 4.91e+04  | 20.3      | 1.6        | 6.7e-09 | 20      |
- | T                   | 1.88e+05  | 5.31      | 6.13       | 4.2e-09 | 29      |
- | *                   | 1.93e+05  | 5.18      | 6.28       | 5e-09   | 20      |
+ | :has(T[length > 1]) |     20000 |      49   |        1   | 5.3e-08 |      20 |
+ | T ~ T ~ T ~ T ~ T   |     34000 |      29   |        1.7 | 5.3e-08 |      20 |
+ | T T2 T3 T4 T5       |     36000 |      28   |        1.7 | 5.3e-08 |      20 |
+ | T                   |    140000 |       7.4 |        6.6 | 1.3e-08 |      20 |
+ | *                   |    140000 |       7.1 |        6.9 | 1.3e-08 |      20 |
  +---------------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DataCSel::Parsing --module-startup >>):
 
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Data::CSel          | 7.9       | 5.3                    | 1          | 2.8e-05 | 21      |
- | perl -e1 (baseline) | 2.6       | 0                      | 3          | 1.5e-05 | 20      |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ #table2#
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Data::CSel          | 0.82                         | 4.2                | 16             |      12   |                    6.5 |        1   | 2.1e-05 |      20 |
+ | perl -e1 (baseline) | 1.6                          | 4.9                | 19             |       5.5 |                    0   |        2.3 | 1.8e-05 |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -137,7 +142,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
