@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataCSel::Selection;
 
-our $DATE = '2016-04-12'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,7 +66,7 @@ Bencher::Scenario::DataCSel::Selection - Benchmark selector
 
 =head1 VERSION
 
-This document describes version 0.03 of Bencher::Scenario::DataCSel::Selection (from Perl distribution Bencher-Scenarios-DataCSel), released on 2016-04-12.
+This document describes version 0.04 of Bencher::Scenario::DataCSel::Selection (from Perl distribution Bencher-Scenarios-DataCSel), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -80,11 +80,18 @@ To run module startup overhead benchmark:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Sample documents from C<PERLANCAR::HTML::Tree::Examples> are used.
+
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Data::CSel> 0.07
+L<Data::CSel> 0.11
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -124,39 +131,37 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DataCSel::Selection >>):
 
- +---------------+------------------+-----------+-----------+------------+---------+---------+
- | dataset       | arg_expr         | rate (/s) | time (ms) | vs_slowest | errors  | samples |
- +---------------+------------------+-----------+-----------+------------+---------+---------+
- | medium1-hash  | Sub4:first-child | 18        | 57        | 1          | 0.0003  | 20      |
- | medium1-array | Sub4:first-child | 18.6      | 53.9      | 1.05       | 4.8e-05 | 20      |
- | medium1-hash  | Sub4             | 24        | 42        | 1.3        | 5.9e-05 | 20      |
- | medium1-array | Sub4             | 23.8      | 42.1      | 1.35       | 3.7e-05 | 20      |
- | small1-hash   | Sub4:first-child | 1.63e+04  | 0.0612    | 927        | 2.7e-08 | 20      |
- | small1-array  | Sub4:first-child | 1.6e+04   | 0.061     | 9.3e+02    | 8e-08   | 20      |
- | small1-hash   | Sub4             | 2.1e+04   | 0.049     | 1.2e+03    | 5e-08   | 23      |
- | small1-array  | Sub4             | 2.1e+04   | 0.048     | 1.2e+03    | 5.3e-08 | 20      |
- +---------------+------------------+-----------+-----------+------------+---------+---------+
+ #table1#
+ +---------------+------------------+-----------+-----------+------------+-----------+---------+
+ | dataset       | arg_expr         | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +---------------+------------------+-----------+-----------+------------+-----------+---------+
+ | medium1-array | Sub4:first-child |        15 |    69     |        1   |   0.00016 |      20 |
+ | medium1-hash  | Sub4:first-child |        15 |    68     |        1   |   0.0002  |      20 |
+ | medium1-hash  | Sub4             |        18 |    55     |        1.3 |   0.00021 |      20 |
+ | medium1-array | Sub4             |        19 |    54     |        1.3 |   0.00019 |      20 |
+ | small1-hash   | Sub4:first-child |     12000 |     0.082 |      830   |   2e-07   |      29 |
+ | small1-array  | Sub4:first-child |     13000 |     0.08  |      860   | 9.4e-08   |      26 |
+ | small1-hash   | Sub4             |     15000 |     0.066 |     1000   | 1.9e-07   |      20 |
+ | small1-array  | Sub4             |     16000 |     0.064 |     1100   | 1.2e-07   |      26 |
+ +---------------+------------------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DataCSel::Selection --module-startup >>):
 
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Data::CSel          | 8.8       | 5.7                    | 1          | 6e-05   | 20      |
- | perl -e1 (baseline) | 3.1       | 0                      | 2.8        | 1.2e-05 | 21      |
- +---------------------+-----------+------------------------+------------+---------+---------+
-
-=head1 DESCRIPTION
-
-Sample documents from C<PERLANCAR::HTML::Tree::Examples> are used.
+ #table2#
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Data::CSel          | 0.82                         | 4.1                | 16             |      14   |                    7.4 |        1   | 5.3e-05 |      20 |
+ | perl -e1 (baseline) | 1.6                          | 5                  | 19             |       6.6 |                    0   |        2.1 | 2.2e-05 |      21 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -180,7 +185,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
